@@ -165,10 +165,10 @@ nsga2 <- function(type = c("binary", "real-valued", "permutation"),
 
     type <- match.arg(type, choices = eval(formals(nsga2)$type))
 
-    algorithm <- "NSGA-II"
-
     callArgs <- list(...)
 
+    callArgs$strategy <- NULL
+
     if (!is.function(population))
         population <- get(population)
     if (!is.function(selection))
@@ -424,10 +424,10 @@ nsga2 <- function(type = c("binary", "real-valued", "permutation"),
         object@crowdingDistance <- cd
 
         if (summary == TRUE) {
-          fitnessSummary[[iter]] <- Summary(object)
+          fitnessSummary[[iter]] <- progress(object, callArgs)
           object@summary <- fitnessSummary
         } else {
-          object@summary <- list()
+          object@summary <- list(NULL)
         }
 
         # Plot front non-dominated by iteration
@@ -445,3 +445,81 @@ nsga2 <- function(type = c("binary", "real-valued", "permutation"),
 
     return(solution)
 }
+
+# @export
+#' @rdname progress-methods
+#' @aliases progress,nsga2-method
+setMethod("progress", "nsga2", .nsga2.progress)
+
+# @export
+#' @rdname plot-methods
+#' @aliases plot,nsga2-method
+setMethod("plot", signature(x="nsga2", y="missing"), .get.plotting)
+
+# @export
+#' @rdname getCrowdingDistance-methods
+#' @aliases getCrowdingDistance,nsga2-method
+setMethod("getCrowdingDistance", "nsga2", function(obj) print(obj@crowdingDistance))
+
+# @export
+#' @rdname summary-methods
+#' @aliases summary,nsga2-method
+setMethod("summary", "nsga2",
+          function(object, ...){
+            callArgs <- list(...)
+            nullRP <- is.null(callArgs$reference_dirs)
+
+            # Calculate information for summary
+
+            first <- object@f[[1]]
+            first_front_fit <-
+              first_front_pop <- object@population[first, ]
+            nadir_point <- apply(object@fitness[first, ], 2, max)
+
+            #first_dum <- object@dumFitness[first, ] for nsga1 summary method
+
+            if("ecr" %in% rownames(utils::installed.packages())){
+              if (nullRP) {
+                cat("Warning! \nReference points not provided:\n
+                      value necessary to evaluate GD and IGD.")
+
+              } else{
+                gd <- ecr::computeGenerationalDistance(t(object@fitness), t(callArgs$reference_dirs))
+                igd <- ecr::computeInvertedGenerationalDistance(t(object@fitness), t(callArgs$reference_dirs))
+              }
+            }
+
+            if("emoa" %in% rownames(utils::installed.packages())){
+              if(nullRP) {
+                cat("\nUsing the maximum in each dimension to evaluate Hypervolumen")
+                reference_point <- nadir_point
+              } else {reference_point <- apply(callArgs$reference_dirs, 2, max)}
+              hv <- emoa::dominated_hypervolume(points = t(object@fitness[first, ]), ref = reference_point)
+            }
+
+            cat("\nSummary of NSGA-II run")
+            cat("\n#====================================")
+            cat("\nNumber of Objectives evaluated: ", ncol(object@fitness))
+            cat("\nTotal iterations: ", object@iter)
+            cat("\nPopulation size: ", object@popSize)
+            #cat("\nFeasible points found: ", nfeas,paste0("(", signif(100 * nfeas / npts, 3), "%"),"of total)")
+            cat("\nNondominated points found: ", length(first),
+                paste0("(", signif(100 * length(first) / object@popSize, 3), "%"),
+                "of total)")
+            cat("\nCrowding distance bounds: ", c(max(object@crowdingDistance), min(object@crowdingDistance)))
+            #cat("\nEstimated nadir point: ", round(object@nadir_point, 3))
+            cat("\nMutation Probability: ",
+                paste0(signif(100 * object@pmutation, 3), "%"))
+            cat("\nCrossover Probability: ",
+                paste0(signif(100 * object@pcrossover, 3), "%"))
+            if("ecr" %in% rownames(utils::installed.packages())){
+              if(!nullRP) cat("\nEstimated IGD: ", igd)
+              if(!nullRP) cat("\nEstimated GD: ", gd)
+            } else cat("\n\nPlease install package 'ecr' to calculate IGD and GD.")
+            if("emoa" %in% rownames(utils::installed.packages())) {
+              cat("\nEstimated HV: ", hv)
+              cat("\nRef point used for HV: ", reference_point)
+            } else cat("\n\nPlease install package 'emoa' to calculate hypervolume.")
+            cat("\n#====================================")
+          }
+)
